"use strict";
const routing_controllers_1 = require("routing-controllers");
const typeorm_1 = require("typeorm");
const class_transformer_1 = require("class-transformer");
const ParamTypes_1 = require("routing-controllers/metadata/types/ParamTypes");
/**
 * Creates entity from the request body.
 */
function EntityFromBody(options) {
    return function (object, methodName, index) {
        const reflectedType = Reflect.getMetadata("design:paramtypes", object, methodName)[index];
        const target = options && options.type ? options.type : reflectedType;
        if (!target)
            throw new Error("Cannot guess type if the parameter");
        routing_controllers_1.defaultMetadataArgsStorage().params.push({
            method: methodName,
            index: index,
            type: ParamTypes_1.ParamTypes.BODY,
            reflectedType: reflectedType,
            parseJson: options && options.parseJson,
            isRequired: options && options.required,
            // format: target,
            target: object.constructor,
            transform: (value) => {
                const connection = typeorm_1.getConnectionManager().get(options ? options.connectionName : undefined);
                function buildMap(target, maps) {
                    if (!!maps.find(map => map.target === target))
                        return maps;
                    const map = { target: target, properties: {} };
                    maps.push(map);
                    connection.getMetadata(target).relations.forEach(relation => {
                        if (relation.type instanceof Function) {
                            map.properties[relation.propertyName] = relation.type;
                            buildMap(relation.type, maps);
                        }
                    });
                    return maps;
                }
                const maps = buildMap(target, []);
                if (options && options.many) {
                    return class_transformer_1.plainToClass(target, value, { targetMaps: maps });
                }
                return class_transformer_1.plainToClass(target, value, { targetMaps: maps });
            }
        });
    };
}
exports.EntityFromBody = EntityFromBody;
//# sourceMappingURL=EntityFromBody.js.map